'use strict';

var _index = require('./index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * The list of all possible AST node types.
 */


// Name

(0, _index2.default)('Name', {
  builder: ['value']
});

// Document

/* eslint-disable no-use-before-define */

(0, _index2.default)('Document', {
  builder: ['definitions'],
  fields: {
    definitions: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Definition'))
    }
  }
}); // experimental non-spec addition.

(0, _index2.default)('OperationDefinition', {
  builder: ['operation', 'selectionSet', 'name', 'variableDefinitions', 'directives'],
  fields: {
    operation: {
      validate: (0, _index.assertValueType)('string')
    },
    name: {
      validate: (0, _index.assertNodeType)('Name'),
      optional: true
    },
    variableDefinitions: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('VariableDefinition')),
      optional: true
    },
    directives: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive')),
      optional: true
    },
    selectionSet: {
      validate: (0, _index.assertNodeType)('SelectionSet')
    }
  },
  aliases: ['Definition']
});

// Note: subscription is an experimental non-spec addition.


(0, _index2.default)('VariableDefinition', {
  builder: ['variable', 'type', 'defaultValue'],
  fields: {
    variable: {
      validate: (0, _index.assertNodeType)('Variable')
    },
    type: {
      validate: (0, _index.assertNodeType)('Type')
    },
    defaultValue: {
      validate: (0, _index.assertNodeType)('Value'),
      optional: true
    }
  },
  alias: ['DefinitionNode']
});

(0, _index2.default)('Variable', {
  builder: ['name'],
  fields: {
    name: {
      validate: (0, _index.assertValueType)('Name')
    }
  }
});

(0, _index2.default)('SelectionSet', {
  builder: ['selections'],
  fields: {
    selections: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Selection'))
    }
  }
});

(0, _index2.default)('Field', {
  builder: ['name', 'alias', 'arguments', 'directives', 'selectionSet'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    alias: {
      validate: (0, _index.assertNodeType)('Name'),
      optional: true
    },
    arguments: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Argument')),
      optional: true
    },
    directives: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive')),
      optional: true
    },
    selectionSet: {
      validate: (0, _index.assertNodeType)('SelectionSet'),
      optional: true
    }
  },
  aliases: ['Selection']
});

(0, _index2.default)('Argument', {
  builder: ['name', 'value'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    value: {
      validate: (0, _index.assertNodeType)('Value')
    }
  }
});

// Fragments

(0, _index2.default)('FragmentSpread', {
  builder: ['name'],
  fields: {
    directives: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive')),
      optional: true
    }
  },
  aliases: ['Selection']
});

(0, _index2.default)('InlineFragment', {
  builder: ['selectionSet', 'typeCondition', 'directives'],
  fields: {
    directives: {
      optional: true,
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive'))
    },
    typeCondition: {
      optional: true,
      validate: (0, _index.assertNodeType)('NamedType')
    },
    selectionSet: {
      validate: (0, _index.assertNodeType)('SelectionSet')
    }
  },
  aliases: ['Selection']
});

(0, _index2.default)('FragmentDefinition', {
  builder: ['name', 'typeCondition', 'selectionSet', 'directives'],
  fields: {
    directives: {
      optional: true,
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive'))
    },
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    typeCondition: {
      validate: (0, _index.assertNodeType)('NamedType')
    },
    selectionSet: {
      validate: (0, _index.assertNodeType)('SelectionSet')
    }
  },
  aliases: ['Definition']
});

// Values

(0, _index2.default)('IntValue', {
  builder: ['value'],
  fields: {
    value: {
      validate: (0, _index.assertValueType)('string')
    }
  },
  aliases: ['Value']
});

(0, _index2.default)('FloatValue', {
  builder: ['value'],
  fields: {
    value: {
      validate: (0, _index.assertValueType)('string')
    }
  },
  aliases: ['Value']
});

(0, _index2.default)('StringValue', {
  builder: ['value'],
  fields: {
    value: {
      validate: (0, _index.assertValueType)('string')
    }
  },
  aliases: ['Value']
});

(0, _index2.default)('BooleanValue', {
  builder: ['value'],
  fields: {
    value: {
      validate: (0, _index.assertValueType)('boolean')
    }
  },
  aliases: ['Value']
});

(0, _index2.default)('NullValue', {
  aliases: ['Value']
});

(0, _index2.default)('EnumValue', {
  builder: ['value'],
  fields: {
    value: {
      validate: (0, _index.assertValueType)('string')
    }
  },
  aliases: ['Value']
});

(0, _index2.default)('ListValue', {
  builder: ['value'],
  fields: {
    value: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Value'))
    }
  },
  aliases: ['Value']
});

(0, _index2.default)('ObjectValue', {
  builder: ['fields'],
  fields: {
    fields: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('ObjectField'))
    }
  },
  aliases: ['Value']
});

(0, _index2.default)('ObjectField', {
  builder: ['name', 'value'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    value: {
      validate: (0, _index.assertValueType)('boolean')
    }
  },
  aliases: ['Value']
});
// Directives

(0, _index2.default)('Directive', {
  builder: ['name', 'arguments'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    arguments: {
      optional: true,
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Argument'))
    }
  }
});

// Type Reference

(0, _index2.default)('NamedType', {
  builder: ['name'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    }
  },
  aliases: ['Type']
});

(0, _index2.default)('ListType', {
  builder: ['type'],
  fields: {
    type: {
      validate: (0, _index.assertNodeType)('Type')
    }
  },
  aliases: ['Type']
});

(0, _index2.default)('NonNullType', {
  builder: ['type'],
  fields: {
    type: {
      validate: (0, _index.assertOneOf)(['NamedType', 'ListType'])
    }
  },
  aliases: ['Type']
});

// Type System Definition

(0, _index2.default)('SchemaDefinition', {
  builder: ['directives', 'operationTypes'],
  fields: {
    directives: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive'))
    },
    operationTypes: {
      validate: (0, _index.chain)((0, _index.assertValueType)('array'), (0, _index.assertEach)((0, _index.assertNodeType)('OperationTypeDefinition')))
    }
  },
  aliases: ['TypeSystemDefinition']
});

(0, _index2.default)('OperationType', {
  builder: ['operation', 'type'],
  fields: {
    operation: {
      validate: (0, _index.assertNodeType)('OperationType')
    },
    type: {
      validate: (0, _index.assertNodeType)('NameType')
    }
  }
});

(0, _index2.default)('ScalarTypeDefinition', {
  buider: ['name', 'directives'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    directives: {
      optional: true,
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive'))
    }
  }
});

(0, _index2.default)('ObjectTypeDefinition', {
  buider: ['name', 'fields', 'directives', 'interfaces'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    directives: {
      optional: true,
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive'))
    },
    interfaces: {
      optional: true,
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('NamedType'))
    },
    fields: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('FieldDefinition'))
    }
  }
});

(0, _index2.default)('FieldDefinition', {
  buider: ['name', 'arguments', 'type', 'directives'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    arguments: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('InputValueDefinition'))
    },
    type: {
      validate: (0, _index.assertNodeType)('Type')
    },
    directives: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive'))
    }
  }
});

(0, _index2.default)('InputValueDefinition', {
  buider: ['name', 'type', 'defaultValue', 'directives'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    type: {
      validate: (0, _index.assertNodeType)('Type')
    },
    defaultValue: {
      validate: (0, _index.assertNodeType)('Value')
    },
    directives: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive'))
    }
  }
});

(0, _index2.default)('InterfaceTypeDefinition', {
  buider: ['name', 'fields', 'directives'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    directives: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive'))
    },
    fields: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('FieldDefinition'))
    }
  }
});

(0, _index2.default)('InputValueDefinition', {
  buider: ['name', 'type', 'directives'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    types: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('NamedType'))
    },
    directives: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive'))
    }
  }
});

(0, _index2.default)('EnumTypeDefinition', {
  buider: ['name', 'values', 'directives'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    values: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('EnumValueDefinition'))
    },
    directives: {
      optional: true,
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive'))
    }
  }
});

(0, _index2.default)('EnumValueDefinition', {
  buider: ['name', 'directives'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    directives: {
      optional: true,
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive'))
    }
  }
});

(0, _index2.default)('InterfaceTypeDefinition', {
  buider: ['name', 'fields', 'directives'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    directives: {
      optional: true,
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Directive'))
    },
    fields: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('InputValueDefinition'))
    }
  }
});

(0, _index2.default)('InterfaceTypeDefinition', {
  buider: ['definition'],
  fields: {
    definition: {
      validate: (0, _index.assertNodeType)('ObjectTypeDefinition')
    }
  }
});

(0, _index2.default)('DirectiveDefinition', {
  buider: ['name', 'locations', 'arguments'],
  fields: {
    name: {
      validate: (0, _index.assertNodeType)('Name')
    },
    locations: {
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('Name'))
    },
    arguments: {
      optional: true,
      validate: (0, _index.assertArrayOf)((0, _index.assertNodeType)('InputValueDefinition'))
    }
  }
});